==> haskell-sandwich-0.1.5.2-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandwich
version:              0.1.5.2
visibility:           public
id:                   sandwich-0.1.5.2-G2rnmc5MWkIH4V5S6JuWIp
key:                  sandwich-0.1.5.2-G2rnmc5MWkIH4V5S6JuWIp
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  770819a8954dee1bca19420b1457edd2
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util Test.Sandwich.Golden.Update
    Test.Sandwich.Internal.Formatters Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/sandwich-0.1.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/sandwich-0.1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.1.5.2-G2rnmc5MWkIH4V5S6JuWIp
depends:
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT
    ansi-terminal-1.0-FJLEfMIg8XB3hMaFI0FBBX
    async-2.2.5-cqcrAyJc5KBpUy7cUuVT7 base-4.16.4.0
    brick-1.7-Awwbnrsi8lv6TqwKBocAPi bytestring-0.11.4.0
    colour-2.3.6-9XZ0UIDKtRjEgaDeW5KVhY containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.2 free-5.2-E0FAQ2pKe9hIj7MIzsBBeZ
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    lifted-async-0.10.2.7-Jsau7OuxLHpInBK3jPoTpY
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.16-8dAPUb0xcemJkOKNZxCZbE
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2
    monad-logger-0.3.41-42xJ9GGFVqWCg9wfad0YAB mtl-2.2.2
    optparse-applicative-0.17.1.0-9B5O8ePYjUG8evKtX1T4ou
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy process-1.6.16.0
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    safe-exceptions-0.1.7.4-GPoXaqbHmse2qLBXsbf3lC stm-2.5.0.2
    string-interpolate-0.3.4.0-6DxkUhu9ocOJBNt5zPVM3c
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    unix-2.7.2.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    vty-5.39-5PlRj3Rmxo39hacJOgj1Js

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandwich-0.1.5.2-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandwich
version:              0.1.5.2
visibility:           public
id:                   sandwich-0.1.5.2-FS8RMjYtHG9GwWa8M84mRl
key:                  sandwich-0.1.5.2-FS8RMjYtHG9GwWa8M84mRl
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  6f31f49125efb5c6be809ed14548c565
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util Test.Sandwich.Golden.Update
    Test.Sandwich.Internal.Formatters Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/sandwich-0.1.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/sandwich-0.1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.1.5.2-FS8RMjYtHG9GwWa8M84mRl
depends:
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT
    ansi-terminal-1.0-FJLEfMIg8XB3hMaFI0FBBX
    async-2.2.5-cqcrAyJc5KBpUy7cUuVT7 base-4.16.4.0
    brick-1.7-EAXlf9saCcWJWw3aqTDhaO bytestring-0.11.4.0
    colour-2.3.6-9XZ0UIDKtRjEgaDeW5KVhY containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.2 free-5.2-E0FAQ2pKe9hIj7MIzsBBeZ
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    lifted-async-0.10.2.7-Jsau7OuxLHpInBK3jPoTpY
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.17-ChCJJ2TX2AIKBqljNVmheD
    monad-control-1.0.3.1-J6JgsySNufR1aBAHpQ3Eh2
    monad-logger-0.3.41-42xJ9GGFVqWCg9wfad0YAB mtl-2.2.2
    optparse-applicative-0.17.1.0-9B5O8ePYjUG8evKtX1T4ou
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy process-1.6.16.0
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    safe-exceptions-0.1.7.4-GPoXaqbHmse2qLBXsbf3lC stm-2.5.0.2
    string-interpolate-0.3.4.0-6DxkUhu9ocOJBNt5zPVM3c
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 transformers-base-0.4.6-ABNpRFPMzKw54ilqxg2n9F
    unix-2.7.2.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    vty-5.39-G2Lac61rqZ65IbwQdhggXV

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
